#
# spec file for package alsa-oss
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           alsa-oss
Version:        1.1.8
Release:        5.5
Summary:        LD_PRELOAD-able library that translates OSS into ALSA calls
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            https://www.alsa-project.org
Source:         %{url}/files/pub/oss-lib/alsa-oss-%{version}.tar.bz2
Source1:        %{url}/files/pub/oss-lib/alsa-oss-%{version}.tar.bz2.sig
Source2:        baselibs.conf
Source3:        %{name}.keyring
BuildRequires:  alsa-devel
BuildRequires:  libtool

%description
A preloadable library that intercepts Open Sound System API calls
in applications and translates them into ALSA API calls.
A convenience script to launch such applications with the preloaded
library is provided as well, called "aoss".

%prep
%setup -q

%build
autoreconf -fi
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
# remove unneeded files
rm -f %{buildroot}%{_libdir}/*.*a
rm -f %{buildroot}%{_libdir}/libalsatoss.so
rm -f %{buildroot}%{_includedir}/*

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
# .so must be in the main package because aoss requires it
%{_libdir}/libaoss.so*
%{_libdir}/libalsatoss.so.*
%{_bindir}/*
%{_mandir}/man*/*

%changelog
* Wed Nov  9 2022 Takashi Iwai <tiwai@suse.com>
- Add tarball signature and keyring
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Use https for URL and SourceURL
* Wed Nov 27 2019 tiwai@suse.de
- Drop the superfluous buildreq alsa-topology-devel again;
  it's no longer mandatory
* Thu Nov 21 2019 tiwai@suse.de
- Fix build breakage by the new alsa update; now it requires
  alsa-topology-devel
* Wed Jan  9 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid repetition of name in summary. Update description.
* Tue Jan  8 2019 tiwai@suse.de
- Update to alsa-oss 1.1.8 (bsc#1181571):
  Fix the build with the recent glibc
- Remove obsoleted patch:
  remove-libio.patch:
* Mon Aug  6 2018 schwab@suse.de
- remove-libio.patch: don't use obsolete <libio.h>
* Wed Apr  4 2018 tiwai@suse.de
- Remove old kludges
- Run spec-cleaner
* Wed Apr  4 2018 tiwai@suse.de
- Update to alsa-oss 1.1.6:
  * Change FSF address (Franklin Street)
- Use %%license file tag
* Wed Jun 18 2014 tiwai@suse.de
- Updated to alsa-oss 1.0.28:
  All pervious fix patches are obsoleted:
  0002-Add-AM_MAINTAINER_MODE-enable-to-configure.in.patch
  0003-Fix-the-argument-passed-to-snd_pcm_dump_setup.patch
  0004-Workaround-for-aoss-dmix-with-unaligned-rates.patch
* Mon Apr 28 2014 tiwai@suse.de
- Fix for dmix with unaligned sample rate:
  0003-Fix-the-argument-passed-to-snd_pcm_dump_setup.patch
  0004-Workaround-for-aoss-dmix-with-unaligned-rates.patch
* Mon Apr 28 2014 tiwai@suse.de
- Revert 0001-Fix-path-to-libaoss.so.patch, as this causes
  regressions on multi-arch (bnc#874331)
* Thu May 23 2013 tiwai@suse.de
- Backport upstream fixes:
  0001-Fix-path-to-libaoss.so.patch
  0002-Add-AM_MAINTAINER_MODE-enable-to-configure.in.patch
* Thu Mar 29 2012 reddwarf@opensuse.org
- stop recommending alsa-oss-32bit
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25;
  pcm: check for XRUN state for GETxSPACE and GETxPTR ioctls
  select: better check for null bit arrays
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Jan 27 2010 jengelh@medozas.de
- package baselibs.conf
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17:
  * just a version bump
* Thu May 15 2008 olh@suse.de
- remove unneeded Recommends: -64bit on ppc (bnc#390761)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Fri Mar  7 2008 sbrabec@suse.cz
- Added bi-arch counterpart Recommends to prevent arch clashes
  (bnc#117079#c14).
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15:
  * Fix dsp->oss_format setting
* Thu May 31 2007 tiwai@suse.de
- updated to version 1.0.14-final
  just version number changes.
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4:
  including HG fixes since 1.0.12
* Mon Apr 16 2007 tiwai@suse.de
- split from alsa package.
